//
// Copyright(C) 1996 Sarrus Software, Inc.
// All rights reserved.
//
// SRCommandProcessor.h
//
#import <foundation/NSObject.h>
#import <foundation/NSDictionary.h>
#import <foundation/NSString.h>
#import <foundation/NSArray.h>

@interface SRCommand : NSObject
{
	@protected
		NSString *name;
		NSString *description;
		NSMutableArray *args;	
		unsigned int minArgs;
		BOOL required;
		SEL action;
		id target;
}

+ commandNamed:(NSString *)name;
- initCommandNamed:(NSString *)commandName;

- (NSString *)name;
- (void)setName:(NSString *)newName;

- (void)setRequired:(BOOL)req;
- (BOOL)required;

- (void)setDescription:(NSString *)commandDescription;
- (NSString *)description;

- (void)setTarget:(NSObject *)someObject action:(SEL)aSelector;
- target;
- (SEL)action;

- (void)setMinimumNumberArguments:(unsigned int)numArgs;
- (unsigned int)minimumNumberArguments;

- (void)addArgument:(NSString *)arg;
- (void)removedArgument:(NSString *)arg;
- (NSArray *)arguments;

- (void)run;

@end

@interface SRCommandProcessor : NSObject
{
	@protected
		NSString *programName;
		NSMutableDictionary *allowableCommands;
		NSMutableDictionary *parsedCommands;
		NSString *commandPrefix;
		unsigned int prefixLength;
}

+ commandProcessor;
- init;

- (void)addCommand:(NSString *)cmdName
		description:(NSString *)cmdDesc
		target:aTarget
		action:(SEL)anAction
		required:(BOOL)isRequired
		minArgs:(unsigned int)minNumberArgs;
- (void)addCommand:(SRCommand *)command;
- (void)removeCommand:(NSString *)name;

- (void)setCommandPrefix:(NSString *)prefix;
- (NSString *)commandPrefix;

- (void)parseCommandLine:(char **)args count:(int)argCount;
- (void)runOptionalCommands;
- (void)runCommand:(NSString *)cmdName;

- (BOOL)checkCommands;

- (NSString *)programName;

@end




