/* main.m
 * 
 * Very simple PMIAPI program to remove appointments and action items 
 * from a PMI calendar file.
 *
 */
#import <appkit/appkit.h>
#import <foundation/NSAutoreleasePool.h>
#import <foundation/NSUtilities.h>
#import <foundation/NSException.h>

#import "PMICalendar.h"

typedef struct _toolInfo 
{
	NSCalendarDate *startDate;
	NSCalendarDate *endDate;
	NSString *calendarName;
	BOOL verbose;
} PMIToolInfo;

void Usage();
int ParseArgs(int argCount, char *args[], PMIToolInfo *info);

int	main(int argc, char *argv[])
{
	NSAutoreleasePool *pool=[[NSAutoreleasePool alloc] init];
	PMICalendar *calendar;
	PMIToolInfo info;

	if (argc < 3) Usage();
	else
	{
		if (ParseArgs(argc, argv, &info))
		{
			calendar = [PMICalendar calendarFromFile:info.calendarName];
			
			if (info.verbose)
			{
				NSEnumerator *apptEnum=[[calendar appointmentsFrom:
						info.startDate until:info.endDate] objectEnumerator];
				NSEnumerator *actionEnum=[[calendar actionItemsFrom:
						info.startDate until:info.endDate] objectEnumerator];
				id <PMIAppointment> appointment;
				id <PMIActionItem> actionItem;

				while (appointment = [apptEnum nextObject])
				{
					NSLog([appointment title]);
					[calendar deleteAppointment:appointment];
				}
				while (actionItem = [actionEnum nextObject])
				{
					NSLog([actionItem title]);
					[calendar deleteActionItem:actionItem];
				}
			}
			else
			{
				[calendar deleteAppointments:
						[calendar appointmentsFrom:info.startDate 
						until:info.endDate]];
				[calendar deleteActionItems:
						[calendar actionItemsFrom:info.startDate 
						until:info.endDate]];

			}
			[calendar save];
		}
		else NSLog(@"Can't open calendar: %s", [info.calendarName cString]);
	}

	[pool release];
	exit(0);
}


int ParseArgs(int argCount, char *args[], PMIToolInfo *info)
{
	NSString *dateFormat=@"%Y-%m-%d";

	info->startDate = PMIFirstDate;
	info->endDate = PMILastDate;
	info->calendarName = nil;
	info->verbose = NO;

	for (volatile int i=1; i < argCount; i++)
	{
		if (args[i][0] != '-')
			NSLog(@"Unrecognized argument \"%s\" (skipping).", args[i]);
		else
		{
			NS_DURING
			switch (args[i][1])
			{
				case 'a':
				case 'A':
				case 'b':
			  	case 'B':
					NSString *dateTime = [NSString 
									stringWithCString:&args[i][2]];

					if (args[i][1] == 'a' || args[i][1] == 'A')
					{
						info->startDate = [NSCalendarDate dateWithString:
								dateTime calendarFormat:dateFormat];
						[info->startDate addYear:0 month:0 day:1 hour:0
						 		minute:0 second:0];
					}
					else
					{
						info->endDate = [NSCalendarDate dateWithString:
								dateTime calendarFormat:dateFormat];
					}
					break;

				case 'f':
				case 'F':
					info->calendarName = [NSString stringWithCString:
										  				&args[i][2]];
					break;

				case 'v':
				case 'V':
					info->verbose = YES;
					break;

				default:
					NSLog(@"Unrecognized argument \"%s\" (skipping).", 
						  args[i]);
					break;
			}

			NS_HANDLER
			NSLog(@"Invalid argument \"%s\"", args[i]);
			break;
			NS_ENDHANDLER
		}
	}

	if (info->calendarName && 
		(info->startDate != PMIFirstDate || info->endDate != PMILastDate))
		return 1;
	else return 0;
}

void Usage()
{
	fprintf(stderr, "Usage:PMIPrune -f<calendar_file> [-b<yyyy-mm-dd>]"
			" [-a<yyyy-mm-dd>] [-v]\n");
	exit(-1);
}





