//
//	Copyright(C) 1995 Sarrus Software, Inc.
// 	All rights reserved.
//
//	PMICalendar.h
//
#import <appkit/appkit.h>
#import <foundation/NSString.h>
#import <foundation/NSDate.h>
#import <foundation/NSArray.h>

#import "PMITypes.h"
#import "PMIAccess.h"
#import "PMIAppointment.h"
#import "PMIActionItem.h"
#import "PMIHoliday.h"

@interface PMICalendar:NSObject
{
	@private
		NSMutableArray * holidayList;
		NSMutableArray *actionItemList;
		NSMutableArray *appointmentList;
		NSString *calendarFilename;
		id database;
}

+ calendar;
+ calendarFromFile:(NSString *)filename;

- initFromCalendarFile:(NSString *)filename;
- init;

- (void)save;
- (void)saveAs:(NSString *)calendarName;

- (NSString *)calendarFilename;
- (void)setCalendarFilename:(NSString *)calendarName;

- (void)update;

- (NSArray *)appointmentsFrom:(NSCalendarDate *)from
	until:(NSCalendarDate *)until;
- (NSArray *)appointmentsWithTag:(PMITag)tag;
- (id <PMIAppointment>)appointmentWithKey:(PMIKey)ref;
- (id <PMIAppointment>)createAppointment;
- (void)deleteAppointment:(id <PMIAppointment>)appointment;
- (void)deleteAppointments:(NSArray *)appointments;

- (NSArray *)actionItemsFrom:(NSCalendarDate *)from
	until:(NSCalendarDate *)until;
- (NSArray *)actionItemsWithTag:(PMITag)tag;
- (id <PMIActionItem>)actionItemWithKey:(PMIKey)ref;
- (id <PMIActionItem>)createActionItem;
- (void)deleteActionItem:(id <PMIActionItem>)actionItem;
- (void)deleteActionItems:(NSArray *)actionItems;

- (NSArray *)holidaysFrom:(NSCalendarDate *)from
	until:(NSCalendarDate *)until;
- (NSArray *)holidaysWithTag:(PMITag)tag;
- (id <PMIHoliday>)holidayWithKey:(PMIKey)ref;
- (id <PMIHoliday>)createHoliday;
- (void)deleteHoliday:(id <PMIHoliday>)holiday;
- (void)deleteHolidays:(NSArray *)holidays;

- (void)setAccessFor:(NSString *)who to:(PMIAccessLevel)accessLevel;
- (PMIAccessLevel)accessFor:(NSString *)who;

- (NSArray *)groupList;
- (void)addToGroupList:(NSString *)who;
- (void)removeFromGroupList:(NSString *)who;

- (NSString *)owner;
- (void)setOwner:(NSString *)owner;

@end
