//
//	Copyright(C) 1995 Sarrus Software, Inc.
//	All rights reserved.
// 
//	PMIEvent.h
//
#import <appkit/appkit.h>
#import <foundation/NSString.h>
#import <foundation/NSArray.h>
#import <foundation/NSDate.h>

#import "PMITypes.h"

typedef enum _pmiRepeatType {
	NoRepeat,
	Daily,
	Weekly,
	BiWeekly,
	Monthly,
	BiMonthly,
	Yearly,
	ThisWeekOfMonth,
	LastWeekOfMonth,
	LastDayOfMonth
} PMIRepeatType;

typedef enum _pmiRepeatDay {
	EverySunday=1,
	EveryMonday=2,
	EveryTuesday=4,
	EveryWednesday=8,
	EveryThursday=16,
	EveryFriday=32,
	EverySaturday=64,
	EveryDay=127
} PMIDayMask;

typedef enum _pmiInvitationResponse {
	Accept = 'Y',
	Decline = 'N',
	Undecided = ' ',
	Owner = 'O',
	Broken = 'B'
} PMIInvitationResponse;

@class PMICalendar;

@protocol PMIEvent <NSObject>

- (NSString *)title;
- (void)setTitle:(NSString *) newTitle;

- (PMICalendar *)calendar;

- (NSString *)creator;

- (PMITag)tag;
- (void)setTag:(PMITag) newTag;

- (PMIKey)key;

- (unsigned int)saveCount;
- (BOOL)hasBeenSaved;

- (void)distributeToCalendar:(NSString *)calendarFilename;
- (void)distributeToCalendars:(NSArray *)calendarFilenames;
- (NSArray *)recipients;

- (BOOL)isDistributed;
- (BOOL)isForeign;

- (void)repeat:(PMIRepeatType)aType withDayMask:(unsigned int)aDayMask 
	until:(NSCalendarDate *)aDate;
- (void)repeat:(PMIRepeatType)aType withDayMask:(unsigned int)aDayMask
	times:(unsigned int)numberTimes;
- (PMIRepeatType)repeatType;
- (unsigned int)repeatDayMask;
- (NSCalendarDate *)repeatEndDate;
- setRepeatEndDate:(NSCalendarDate *)newEndDate;

@end
